.. paidiverpy documentation master file, created by
   sphinx-quickstart on Wed May  5 22:45:36 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: _static/logo_paidiver_docs.png
    :alt: Paidiverpy

|lifecycle| |License| |Documentation| |DOI| |Pypi|


Paidiverpy Docs
===============

**Paidiverpy** is a Python package designed to create pipelines for preprocessing image data for biodiversity analysis.


.. admonition:: Note

  This package is still in active development, and frequent updates and changes are expected. The API and features may evolve as we continue improving it.

  Comprehensive documentation is forthcoming.


Documentation
-------------

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    why
    install
    usage
    package_organisation
    configuration_file
    images_metadata
    images_layer
    preprocessing_steps
    example_data
    gui
    gallery
    scientific_background
    benchmarks

.. toctree::
    :maxdepth: 2
    :caption: User Guide

    guide/performance/index
    guide/custom_algorithms/index
    guide/remote_data
    guide/image_formats/index
    guide/rename_images/index
    guide/export_validate_metadata/index
    guide/test_mode/index

.. toctree::
    :maxdepth: 2
    :caption: Help & Reference

    contributing
    api


.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`



.. |License| image:: https://img.shields.io/badge/license-Apache%202.0-blue?style=flat-square
    :target: https://www.apache.org/licenses/
.. .. |Python version| image:: https://img.shields.io/pypi/pyversions/paidiverpy
..    :target: //pypi.org/project/paidiverpy/
.. .. |Anaconda-Server Badge| image:: https://anaconda.org/conda-forge/paidiverpy/badges/platforms.svg
..    :target: https://anaconda.org/conda-forge/paidiverpy
.. |lifecycle| image:: https://img.shields.io/badge/lifecycle-experimental-green.svg
   :target: https://www.tidyverse.org/lifecycle/#stable
.. |DOI| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.14641878.svg
   :target: https://doi.org/10.5281/zenodo.14641878
.. |Documentation| image:: https://img.shields.io/readthedocs/paidiverpy?logo=readthedocs
    :target: https://paidiverpy.readthedocs.io/en/latest/?badge=latest
.. |Pypi| image:: https://img.shields.io/pypi/v/paidiverpy
    :target: https://pypi.org/project/paidiverpy/
